@@ -1,5 +1,21 @@
 context("utils")
 
+test_that("err", {
+  expect_error(err(), "^$")
+  expect_error(err(1,2), "^12$")
+  expect_error(err(NULL), "character[(]0[)]")
+})
+
+test_that("wrn", {
+  expect_warning(wrn(), "^$")
+  expect_warning(wrn(1,2), "^12$")
+})
+
+test_that("msg", {
+  expect_message(msg(), "^\n$")
+  expect_message(msg(1,2), "^12\n$")
+})
+
 test_that("p", {
   expect_identical(p(character(0)), character(0))
   expect_identical(p("e"), "e")
